# GlyphDeck

Streamlined asynchronous natural language categorisation & sentiment analysis using generative AI.

> [!IMPORTANT]
> Don't sweat it, there's more to come, this README is a work in progress